@@ -15,7 +15,7 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 #{{{sub new
 
@@ -46,6 +46,28 @@ sub me {
 
 #}}}
 
+#{{{sub profile_update
+sub profile_update {
+    my ( $user, $field, $value, $act_on_user, $profile_section ) = @_;
+    my $res = Apache::Sling::Request::request(
+        \$user,
+        Sakai::Nakamura::UserUtil::profile_update_setup(
+            $user->{'BaseURL'}, $field, $value,
+            $act_on_user,       $profile_section
+        )
+    );
+    my $success = Sakai::Nakamura::UserUtil::profile_update_eval($res);
+    my $message = (
+        $success
+        ? 'Profile successfully updated'
+        : 'Problem fetching details for current user'
+    );
+    $user->set_results( "$message", $res );
+    return $success;
+}
+
+#}}}
+
 1;
 
 __END__
@@ -64,6 +86,14 @@ user related functionality for Sling implemented over rest APIs.
 
 Create, set up, and return a User Agent.
 
+=head2 me
+
+Fetch output from the sakai me service for the logged in user
+
+=head2 profile_update
+
+Update a value in the user profile
+
 =head1 USAGE
 
 use Sakai::Nakamura::User;
@@ -110,4 +140,4 @@ Daniel David Parry <perl@ddp.me.uk>
 
 LICENSE: http://dev.perl.org/licenses/artistic.html
 
-COPYRIGHT: (c) 2010 Daniel David Parry <perl@ddp.me.uk>
+COPYRIGHT: (c) 2011 Daniel David Parry <perl@ddp.me.uk>
